@@ -19,7 +19,7 @@
 #include "Settings.h"
 #include "ViewManager.h"
 #include "progresstree/ProgressTreeView.h"
-#include "utils/CalamaresUtilsGui.h"
+#include "utils/Gui.h"
 #include "utils/Logger.h"
 #include "utils/Qml.h"
 #include "utils/Retranslator.h"
@@ -27,7 +27,9 @@
 #include <QApplication>
 #include <QBoxLayout>
 #include <QCloseEvent>
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
 #include <QDesktopWidget>
+#endif
 #include <QFile>
 #include <QFileInfo>
 #include <QLabel>
@@ -39,6 +41,16 @@
 #endif
 #include <QTreeView>
 
+static QSize
+desktopSize( QWidget* w )
+{
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
+    return qApp->desktop()->availableGeometry( w ).size();
+#else
+    return w->screen()->availableGeometry().size();
+#endif
+}
+
 static inline int
 windowDimensionToPixels( const Calamares::Branding::WindowDimension& u )
 {
@@ -52,7 +64,7 @@ windowDimensionToPixels( const Calamares::Branding::WindowDimension& u )
     }
     if ( u.unit() == Calamares::Branding::WindowDimensionUnit::Fonties )
     {
-        return static_cast< int >( u.value() * CalamaresUtils::defaultFontHeight() );
+        return static_cast< int >( u.value() * Calamares::defaultFontHeight() );
     }
     return 0;
 }
@@ -133,21 +145,18 @@ getWidgetSidebar( Calamares::DebugWindowManager* debug,
     QHBoxLayout* extraButtons = new QHBoxLayout;
     sideLayout->addLayout( extraButtons );
 
-    const int defaultFontHeight = CalamaresUtils::defaultFontHeight();
+    const int defaultFontHeight = Calamares::defaultFontHeight();
 
     if ( /* About-Calamares Button enabled */ true )
     {
         QPushButton* aboutDialog = new QPushButton;
         aboutDialog->setObjectName( "aboutButton" );
-        aboutDialog->setIcon( CalamaresUtils::defaultPixmap( CalamaresUtils::Information,
-                                                             CalamaresUtils::Original,
-                                                             2 * QSize( defaultFontHeight, defaultFontHeight ) ) );
+        aboutDialog->setIcon( Calamares::defaultPixmap(
+            Calamares::Information, Calamares::Original, 2 * QSize( defaultFontHeight, defaultFontHeight ) ) );
         CALAMARES_RETRANSLATE_FOR(
-            aboutDialog,
-            aboutDialog->setText(
-                QCoreApplication::translate( CalamaresWindow::staticMetaObject.className(), "About" ) );
-            aboutDialog->setToolTip( QCoreApplication::translate( CalamaresWindow::staticMetaObject.className(),
-                                                                  "Show information about Calamares" ) ); );
+            aboutDialog, aboutDialog->setText( QCoreApplication::translate( "calamares-sidebar", "About", "@button" ) );
+            aboutDialog->setToolTip(
+                QCoreApplication::translate( "calamares-sidebar", "Show information about Calamares", "@tooltip" ) ); );
         extraButtons->addWidget( aboutDialog );
         aboutDialog->setFlat( true );
         aboutDialog->setCheckable( true );
@@ -157,13 +166,13 @@ getWidgetSidebar( Calamares::DebugWindowManager* debug,
     {
         QPushButton* debugWindowBtn = new QPushButton;
         debugWindowBtn->setObjectName( "debugButton" );
-        debugWindowBtn->setIcon( CalamaresUtils::defaultPixmap(
-            CalamaresUtils::Bugs, CalamaresUtils::Original, 2 * QSize( defaultFontHeight, defaultFontHeight ) ) );
-        CALAMARES_RETRANSLATE_FOR( debugWindowBtn,
-                                   debugWindowBtn->setText( QCoreApplication::translate(
-                                       CalamaresWindow::staticMetaObject.className(), "Debug" ) );
-                                   debugWindowBtn->setToolTip( QCoreApplication::translate(
-                                       CalamaresWindow::staticMetaObject.className(), "Show debug information" ) ); );
+        debugWindowBtn->setIcon( Calamares::defaultPixmap(
+            Calamares::Bugs, Calamares::Original, 2 * QSize( defaultFontHeight, defaultFontHeight ) ) );
+        CALAMARES_RETRANSLATE_FOR(
+            debugWindowBtn,
+            debugWindowBtn->setText( QCoreApplication::translate( "calamares-sidebar", "Debug", "@button" ) );
+            debugWindowBtn->setToolTip(
+                QCoreApplication::translate( "calamares-sidebar", "Show debug information", "@tooltip" ) ); );
         extraButtons->addWidget( debugWindowBtn );
         debugWindowBtn->setFlat( true );
         debugWindowBtn->setCheckable( true );
@@ -172,7 +181,7 @@ getWidgetSidebar( Calamares::DebugWindowManager* debug,
             debug, &Calamares::DebugWindowManager::visibleChanged, debugWindowBtn, &QPushButton::setChecked );
     }
 
-    CalamaresUtils::unmarginLayout( sideLayout );
+    Calamares::unmarginLayout( sideLayout );
     return sideBox;
 }
 
@@ -189,10 +198,10 @@ getWidgetNavigation( Calamares::DebugWindowManager*,
 
     // Create buttons and sets an initial icon; the icons may change
     {
-        auto* back
-            = new QPushButton( getButtonIcon( QStringLiteral( "go-previous" ) ),
-                               QCoreApplication::translate( CalamaresWindow::staticMetaObject.className(), "&Back" ),
-                               navigation );
+        auto* back = new QPushButton(
+            getButtonIcon( QStringLiteral( "go-previous" ) ),
+            QCoreApplication::translate( CalamaresWindow::staticMetaObject.className(), "&Back", "@button" ),
+            navigation );
         back->setObjectName( "view-button-back" );
         back->setEnabled( viewManager->backEnabled() );
         QObject::connect( back, &QPushButton::clicked, viewManager, &Calamares::ViewManager::back );
@@ -205,10 +214,10 @@ getWidgetNavigation( Calamares::DebugWindowManager*,
         bottomLayout->addWidget( back );
     }
     {
-        auto* next
-            = new QPushButton( getButtonIcon( QStringLiteral( "go-next" ) ),
-                               QCoreApplication::translate( CalamaresWindow::staticMetaObject.className(), "&Next" ),
-                               navigation );
+        auto* next = new QPushButton(
+            getButtonIcon( QStringLiteral( "go-next" ) ),
+            QCoreApplication::translate( CalamaresWindow::staticMetaObject.className(), "&Next", "@button" ),
+            navigation );
         next->setObjectName( "view-button-next" );
         next->setEnabled( viewManager->nextEnabled() );
         QObject::connect( next, &QPushButton::clicked, viewManager, &Calamares::ViewManager::next );
@@ -222,10 +231,10 @@ getWidgetNavigation( Calamares::DebugWindowManager*,
     }
     bottomLayout->addSpacing( 12 );
     {
-        auto* quit
-            = new QPushButton( getButtonIcon( QStringLiteral( "dialog-cancel" ) ),
-                               QCoreApplication::translate( CalamaresWindow::staticMetaObject.className(), "&Cancel" ),
-                               navigation );
+        auto* quit = new QPushButton(
+            getButtonIcon( QStringLiteral( "dialog-cancel" ) ),
+            QCoreApplication::translate( CalamaresWindow::staticMetaObject.className(), "&Cancel", "@button" ),
+            navigation );
         quit->setObjectName( "view-button-cancel" );
         QObject::connect( quit, &QPushButton::clicked, viewManager, &Calamares::ViewManager::quit );
         QObject::connect( viewManager, &Calamares::ViewManager::quitEnabledChanged, quit, &QPushButton::setEnabled );
@@ -267,7 +276,6 @@ setDimension( QQuickWidget* w, Qt::Orientation o, int desiredWidth )
     w->setResizeMode( QQuickWidget::SizeRootObjectToView );
 }
 
-
 static QWidget*
 getQmlSidebar( Calamares::DebugWindowManager* debug,
                Calamares::ViewManager*,
@@ -275,15 +283,15 @@ getQmlSidebar( Calamares::DebugWindowManager* debug,
                Qt::Orientation o,
                int desiredWidth )
 {
-    CalamaresUtils::registerQmlModels();
+    Calamares::registerQmlModels();
     QQuickWidget* w = new QQuickWidget( parent );
     if ( debug )
     {
         w->engine()->rootContext()->setContextProperty( "debug", debug );
     }
 
-    w->setSource( QUrl(
-        CalamaresUtils::searchQmlFile( CalamaresUtils::QmlSearch::Both, QStringLiteral( "calamares-sidebar" ) ) ) );
+    w->setSource(
+        QUrl( Calamares::searchQmlFile( Calamares::QmlSearch::Both, QStringLiteral( "calamares-sidebar" ) ) ) );
     setDimension( w, o, desiredWidth );
     return w;
 }
@@ -295,14 +303,14 @@ getQmlNavigation( Calamares::DebugWindowManager* debug,
                   Qt::Orientation o,
                   int desiredWidth )
 {
-    CalamaresUtils::registerQmlModels();
+    Calamares::registerQmlModels();
     QQuickWidget* w = new QQuickWidget( parent );
     if ( debug )
     {
         w->engine()->rootContext()->setContextProperty( "debug", debug );
     }
-    w->setSource( QUrl(
-        CalamaresUtils::searchQmlFile( CalamaresUtils::QmlSearch::Both, QStringLiteral( "calamares-navigation" ) ) ) );
+    w->setSource(
+        QUrl( Calamares::searchQmlFile( Calamares::QmlSearch::Both, QStringLiteral( "calamares-navigation" ) ) ) );
     setDimension( w, o, desiredWidth );
     return w;
 }
@@ -383,7 +391,7 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
     , m_debugManager( new Calamares::DebugWindowManager( this ) )
     , m_viewManager( nullptr )
 {
-    installEventFilter( CalamaresUtils::Retranslator::instance() );
+    installEventFilter( Calamares::Retranslator::instance() );
 
     // If we can never cancel, don't show the window-close button
     if ( Calamares::Settings::instance()->disableCancel() )
@@ -391,6 +399,7 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
         setWindowFlag( Qt::WindowCloseButtonHint, false );
     }
 
+    // %1 is the distribution name
     CALAMARES_RETRANSLATE( const auto* branding = Calamares::Branding::instance();
                            setWindowTitle( Calamares::Settings::instance()->isSetupMode()
                                                ? tr( "%1 Setup Program" ).arg( branding->productName() )
@@ -399,17 +408,17 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
     const Calamares::Branding* const branding = Calamares::Branding::instance();
     using ImageEntry = Calamares::Branding::ImageEntry;
 
-    using CalamaresUtils::windowMinimumHeight;
-    using CalamaresUtils::windowMinimumWidth;
-    using CalamaresUtils::windowPreferredHeight;
-    using CalamaresUtils::windowPreferredWidth;
+    using Calamares::windowMinimumHeight;
+    using Calamares::windowMinimumWidth;
+    using Calamares::windowPreferredHeight;
+    using Calamares::windowPreferredWidth;
 
     using PanelSide = Calamares::Branding::PanelSide;
 
     // Needs to match what's checked in DebugWindow
     this->setObjectName( "mainApp" );
 
-    QSize availableSize = qApp->desktop()->availableGeometry( this ).size();
+    QSize availableSize = desktopSize( this );
     QSize minimumSize( qBound( windowMinimumWidth, availableSize.width(), windowPreferredWidth ),
                        qBound( windowMinimumHeight, availableSize.height(), windowPreferredHeight ) );
     setMinimumSize( minimumSize );
@@ -429,7 +438,7 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
     {
         QWidget* label = new QWidget( this );
         QVBoxLayout* l = new QVBoxLayout;
-        CalamaresUtils::unmarginLayout( l );
+        Calamares::unmarginLayout( l );
         l->addWidget( label );
         setLayout( l );
         label->setObjectName( "backgroundWidget" );
@@ -458,14 +467,14 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
     QBoxLayout* contentsLayout = new QVBoxLayout;
     contentsLayout->setSpacing( 0 );
 
-    QWidget* sideBox = flavoredWidget(
-        branding->sidebarFlavor(),
-        ::orientation( branding->sidebarSide() ),
-        m_debugManager,
-        baseWidget,
-        ::getWidgetSidebar,
-        ::getQmlSidebar,
-        qBound( 100, CalamaresUtils::defaultFontHeight() * 12, w < windowPreferredWidth ? 100 : 190 ) );
+    QWidget* sideBox
+        = flavoredWidget( branding->sidebarFlavor(),
+                          ::orientation( branding->sidebarSide() ),
+                          m_debugManager,
+                          baseWidget,
+                          ::getWidgetSidebar,
+                          ::getQmlSidebar,
+                          qBound( 100, Calamares::defaultFontHeight() * 12, w < windowPreferredWidth ? 100 : 190 ) );
     QWidget* navigation = flavoredWidget( branding->navigationFlavor(),
                                           ::orientation( branding->navigationSide() ),
                                           m_debugManager,
@@ -497,8 +506,8 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
         ( contentsLayout->count() > 1 ? Qt::Orientations( Qt::Horizontal ) : Qt::Orientations() )
         | ( mainLayout->count() > 1 ? Qt::Orientations( Qt::Vertical ) : Qt::Orientations() ) );
 
-    CalamaresUtils::unmarginLayout( mainLayout );
-    CalamaresUtils::unmarginLayout( contentsLayout );
+    Calamares::unmarginLayout( mainLayout );
+    Calamares::unmarginLayout( contentsLayout );
     baseWidget->setLayout( mainLayout );
     setStyleSheet( Calamares::Branding::instance()->stylesheet() );
 }
@@ -507,7 +516,7 @@ void
 CalamaresWindow::ensureSize( QSize size )
 {
     auto mainGeometry = this->geometry();
-    QSize availableSize = qApp->desktop()->availableGeometry( this ).size();
+    QSize availableSize = desktopSize( this );
 
     // We only care about vertical sizes that are big enough
     int embiggenment = qMax( 0, size.height() - m_viewManager->centralWidget()->size().height() );
