@@ -25,20 +25,25 @@
 #include "modulesystem/ViewModule.h"
 #include "utils/Logger.h"
 #include "utils/Retranslator.h"
+#include "utils/System.h"
 #include "utils/Yaml.h"
 #include "viewpages/ExecutionViewStep.h"
 
 // Optional features of Calamares
-// - Python support
+// - Python support with pybind11
+// - Python support with older Boost implementation
 // - QML support
 #ifdef WITH_PYTHON
+#if WITH_PYBIND11
+#include "python/PythonJob.h"
+#else
 #include "PythonJob.h"
 #endif
+#endif
 #ifdef WITH_QML
 #include "utils/Qml.h"
 #endif
 
-
 #include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
@@ -60,6 +65,7 @@ struct ModuleConfig
     QString m_module;
     QString m_jobConfig;
     QString m_globalConfig;
+    QString m_settingsConfig;
     QString m_language;
     QString m_branding;
     bool m_ui;
@@ -71,22 +77,23 @@ handle_args( QCoreApplication& a )
 {
     QCommandLineOption debugLevelOption(
         QStringLiteral( "D" ), "Verbose output for debugging purposes (0-8), ignored.", "level" );
-    QCommandLineOption globalOption( QStringList() << QStringLiteral( "g" ) << QStringLiteral( "global " ),
-                                     QStringLiteral( "Global settings document" ),
+    QCommandLineOption settingsOption( { QStringLiteral( "S" ), QStringLiteral( "settings" ) },
+                                       QStringLiteral( "Settings.conf document" ),
+                                       QString( "settings.conf" ) );
+    QCommandLineOption globalOption( { QStringLiteral( "g" ), QStringLiteral( "global" ) },
+                                     QStringLiteral( "Global storage settings document" ),
                                      "global.yaml" );
-    QCommandLineOption jobOption( QStringList() << QStringLiteral( "j" ) << QStringLiteral( "job" ),
-                                  QStringLiteral( "Job settings document" ),
-                                  "job.yaml" );
-    QCommandLineOption langOption( QStringList() << QStringLiteral( "l" ) << QStringLiteral( "language" ),
+    QCommandLineOption jobOption(
+        { QStringLiteral( "j" ), QStringLiteral( "job" ) }, QStringLiteral( "Job settings document" ), "job.yaml" );
+    QCommandLineOption langOption( { QStringLiteral( "l" ), QStringLiteral( "language" ) },
                                    QStringLiteral( "Language (global)" ),
                                    "languagecode" );
-    QCommandLineOption brandOption( QStringList() << QStringLiteral( "b" ) << QStringLiteral( "branding" ),
+    QCommandLineOption brandOption( { QStringLiteral( "b" ), QStringLiteral( "branding" ) },
                                     QStringLiteral( "Branding directory" ),
                                     "path/to/branding.desc",
                                     "src/branding/default/branding.desc" );
-    QCommandLineOption uiOption( QStringList() << QStringLiteral( "U" ) << QStringLiteral( "ui" ),
-                                 QStringLiteral( "Enable UI" ) );
-    QCommandLineOption slideshowOption( QStringList() << QStringLiteral( "s" ) << QStringLiteral( "slideshow" ),
+    QCommandLineOption uiOption( { QStringLiteral( "U" ), QStringLiteral( "ui" ) }, QStringLiteral( "Enable UI" ) );
+    QCommandLineOption slideshowOption( { QStringLiteral( "s" ), QStringLiteral( "slideshow" ) },
                                         QStringLiteral( "Run slideshow module" ) );
     QCommandLineParser parser;
     parser.setApplicationDescription( "Calamares module tester" );
@@ -94,6 +101,7 @@ handle_args( QCoreApplication& a )
     parser.addVersionOption();
 
     parser.addOption( debugLevelOption );
+    parser.addOption( settingsOption );
     parser.addOption( globalOption );
     parser.addOption( jobOption );
     parser.addOption( langOption );
@@ -101,7 +109,7 @@ handle_args( QCoreApplication& a )
     parser.addOption( uiOption );
     parser.addOption( slideshowOption );
 #ifdef WITH_PYTHON
-    QCommandLineOption pythonOption( QStringList() << QStringLiteral( "P" ) << QStringLiteral( "no-injected-python" ),
+    QCommandLineOption pythonOption( { QStringLiteral( "P" ), QStringLiteral( "no-injected-python" ) },
                                      QStringLiteral( "Do not disable potentially-harmful Python commands" ) );
     parser.addOption( pythonOption );
 #endif
@@ -140,11 +148,11 @@ handle_args( QCoreApplication& a )
         return ModuleConfig { parser.isSet( slideshowOption ) ? QStringLiteral( "-" ) : args.first(),
                               jobSettings,
                               parser.value( globalOption ),
+                              parser.value( settingsOption ),
                               parser.value( langOption ),
                               parser.value( brandOption ),
                               parser.isSet( slideshowOption ) || parser.isSet( uiOption ),
-                              pythonInjection
-        };
+                              pythonInjection };
     }
 }
 
@@ -213,10 +221,11 @@ ExecViewModule::ExecViewModule()
 {
     // Normally the module-loader gives the module an instance key
     // (out of the settings file, or the descriptor of the module).
-    // We don't have one, so build one -- this gives us "x@x".
+    // We don't have one, so build one -- this gives us "execView@execView".
     QVariantMap m;
-    m.insert( "name", "x" );
-    Calamares::Module::initFrom( Calamares::ModuleSystem::Descriptor::fromDescriptorData( m ), "x" );
+    const QString execView = QStringLiteral( "execView" );
+    m.insert( "name", execView );
+    Calamares::Module::initFrom( Calamares::ModuleSystem::Descriptor::fromDescriptorData( m, execView ), execView );
 }
 
 ExecViewModule::~ExecViewModule() {}
@@ -243,7 +252,6 @@ ExecViewModule::type() const
     return Module::Type::View;
 }
 
-
 Calamares::Module::Interface
 ExecViewModule::interface() const
 {
@@ -294,18 +302,19 @@ load_module( const ModuleConfig& moduleConfig )
         return new ExecViewModule;
     }
 
-    QFileInfo fi;
+    QFileInfo fi;  // This is kept around to hold the path of the module descriptor
 
     bool ok = false;
     QVariantMap descriptor;
 
-    for ( const QString& prefix : QStringList { "./", "src/modules/", "modules/" } )
+    QStringList moduleDirectories { "./", "src/modules/", "modules/", CMAKE_INSTALL_FULL_LIBDIR "/calamares/modules/" };
+    for ( const QString& prefix : qAsConst( moduleDirectories ) )
     {
         // Could be a complete path, eg. src/modules/dummycpp/module.desc
         fi = QFileInfo( prefix + moduleName );
         if ( fi.exists() && fi.isFile() )
         {
-            descriptor = CalamaresUtils::loadYaml( fi, &ok );
+            descriptor = Calamares::YAML::load( fi, &ok );
         }
         if ( ok )
         {
@@ -319,18 +328,29 @@ load_module( const ModuleConfig& moduleConfig )
             fi = QFileInfo( prefix + moduleName + "/module.desc" );
             if ( fi.exists() && fi.isFile() )
             {
-                descriptor = CalamaresUtils::loadYaml( fi, &ok );
+                descriptor = Calamares::YAML::load( fi, &ok );
             }
             if ( ok )
             {
                 break;
             }
+            else
+            {
+                if ( !fi.exists() )
+                {
+                    cDebug() << "Expected a descriptor file" << fi.path();
+                }
+                else
+                {
+                    cDebug() << "Read descriptor" << fi.path() << "and it was empty.";
+                }
+            }
         }
     }
 
     if ( !ok )
     {
-        cWarning() << "No suitable module descriptor found.";
+        cWarning() << "No suitable module descriptor found in" << Logger::DebugList( moduleDirectories );
         return nullptr;
     }
 
@@ -348,7 +368,10 @@ load_module( const ModuleConfig& moduleConfig )
     cDebug() << Logger::SubEntry << "Module" << moduleName << "job-configuration:" << configFile;
 
     Calamares::Module* module = Calamares::moduleFromDescriptor(
-        Calamares::ModuleSystem::Descriptor::fromDescriptorData( descriptor ), name, configFile, moduleDirectory );
+        Calamares::ModuleSystem::Descriptor::fromDescriptorData( descriptor, fi.absoluteFilePath() ),
+        name,
+        configFile,
+        moduleDirectory );
 
     return module;
 }
@@ -442,8 +465,10 @@ main( int argc, char* argv[] )
         return 1;
     }
 
-    std::unique_ptr< Calamares::Settings > settings_p( Calamares::Settings::init( QString() ) );
+    std::unique_ptr< Calamares::Settings > settings_p( Calamares::Settings::init( module.m_settingsConfig ) );
     std::unique_ptr< Calamares::JobQueue > jobqueue_p( new Calamares::JobQueue( nullptr ) );
+    std::unique_ptr< Calamares::System > system_p( new Calamares::System( settings_p->doChroot() ) );
+
     QMainWindow* mw = nullptr;
 
     auto* gs = jobqueue_p->globalStorage();
@@ -461,11 +486,16 @@ main( int argc, char* argv[] )
 #ifdef WITH_PYTHON
     if ( module.m_pythonInjection )
     {
-        Calamares::PythonJob::setInjectedPreScript(pythonPreScript);
+#if WITH_PYBIND11
+        Calamares::Python::Job::setInjectedPreScript( pythonPreScript );
+#else
+        // Old Boost approach
+        Calamares::PythonJob::setInjectedPreScript( pythonPreScript );
+#endif
     }
 #endif
 #ifdef WITH_QML
-    CalamaresUtils::initQmlModulesDir();  // don't care if failed
+    Calamares::initQmlModulesDir();  // don't care if failed
 #endif
 
     cDebug() << "Calamares module-loader testing" << module.moduleName();
@@ -476,7 +506,7 @@ main( int argc, char* argv[] )
         return 1;
     }
 
-    cDebug() << Logger::SubEntry << " .. got" << m->name() << m->typeString() << m->interfaceString();
+    cDebug() << Logger::SubEntry << "got" << m->name() << m->typeString() << m->interfaceString();
     if ( m->type() == Calamares::Module::Type::View )
     {
         // If we forgot the --ui, any ViewModule will core dump as it
@@ -492,7 +522,7 @@ main( int argc, char* argv[] )
         mw = module.m_ui ? new QMainWindow() : nullptr;
         if ( mw )
         {
-            mw->installEventFilter( CalamaresUtils::Retranslator::instance() );
+            mw->installEventFilter( Calamares::Retranslator::instance() );
         }
 
         (void)new Calamares::Branding( module.m_branding );
@@ -526,7 +556,7 @@ main( int argc, char* argv[] )
 
     using TR = Logger::DebugRow< const char*, const QString >;
 
-    cDebug() << "Module metadata" << TR( "name", m->name() ) << TR( "type", m->typeString() )
+    cDebug() << Logger::SubEntry << "Module metadata" << TR( "name", m->name() ) << TR( "type", m->typeString() )
              << TR( "interface", m->interfaceString() );
 
     Calamares::JobList jobList = m->jobs();
@@ -534,6 +564,8 @@ main( int argc, char* argv[] )
     unsigned int count = 1;
     for ( const auto& p : jobList )
     {
+        // This doesn't get a SubEntry because the jobs may log a bunch of
+        // things; print the function-header to make clear that we're back in main.
         cDebug() << "Job #" << count << "name" << p->prettyName();
         Calamares::JobResult r = p->exec();
         if ( !r )
