@@ -13,22 +13,23 @@
 #include "GlobalStorage.h"
 #include "JobQueue.h"
 
-// #include "utils/CalamaresUtils.h"
-#include "utils/CalamaresUtilsSystem.h"
+#include "compat/Variant.h"
 #include "utils/Logger.h"
+#include "utils/StringExpander.h"
+#include "utils/System.h"
 #include "utils/Variant.h"
 
 #include <QCoreApplication>
 #include <QVariantList>
 
-namespace CalamaresUtils
+namespace Calamares
 {
 
 static CommandLine
 get_variant_object( const QVariantMap& m )
 {
-    QString command = CalamaresUtils::getString( m, "command" );
-    qint64 timeout = CalamaresUtils::getInteger( m, "timeout", -1 );
+    QString command = Calamares::getString( m, "command" );
+    qint64 timeout = Calamares::getInteger( m, "timeout", -1 );
 
     if ( !command.isEmpty() )
     {
@@ -45,11 +46,11 @@ get_variant_stringlist( const QVariantList& l )
     unsigned int count = 0;
     for ( const auto& v : l )
     {
-        if ( v.type() == QVariant::String )
+        if ( Calamares::typeOf( v ) == Calamares::StringVariantType )
         {
             retl.append( CommandLine( v.toString(), CommandLine::TimeoutNotSet() ) );
         }
-        else if ( v.type() == QVariant::Map )
+        else if ( Calamares::typeOf( v ) == Calamares::MapVariantType )
         {
             auto command( get_variant_object( v.toMap() ) );
             if ( command.isValid() )
@@ -60,13 +61,54 @@ get_variant_stringlist( const QVariantList& l )
         }
         else
         {
-            cWarning() << "Bad CommandList element" << count << v.type() << v;
+            cWarning() << "Bad CommandList element" << count << v;
         }
         ++count;
     }
     return retl;
 }
 
+static Calamares::String::DictionaryExpander
+get_gs_expander( System::RunLocation location )
+{
+    Calamares::GlobalStorage* gs = Calamares::JobQueue::instance()->globalStorage();
+
+    Calamares::String::DictionaryExpander expander;
+
+    // Figure out the replacement for ${ROOT}
+    if ( location == System::RunLocation::RunInTarget )
+    {
+        expander.insert( QStringLiteral( "ROOT" ), QStringLiteral( "/" ) );
+    }
+    else if ( gs && gs->contains( "rootMountPoint" ) )
+    {
+        expander.insert( QStringLiteral( "ROOT" ), gs->value( "rootMountPoint" ).toString() );
+    }
+
+    // Replacement for ${USER}
+    if ( gs && gs->contains( "username" ) )
+    {
+        expander.insert( QStringLiteral( "USER" ), gs->value( "username" ).toString() );
+    }
+
+    return expander;
+}
+
+CommandLine
+CommandLine::expand( KMacroExpanderBase& expander ) const
+{
+    QString c = first;
+    expander.expandMacrosShellQuote( c );
+    return { c, second };
+}
+
+Calamares::CommandLine
+CommandLine::expand() const
+{
+    auto expander = get_gs_expander( System::RunLocation::RunInHost );
+    return expand( expander );
+}
+
 CommandList::CommandList( bool doChroot, std::chrono::seconds timeout )
     : m_doChroot( doChroot )
     , m_timeout( timeout )
@@ -76,7 +118,7 @@ CommandList::CommandList( bool doChroot, std::chrono::seconds timeout )
 CommandList::CommandList::CommandList( const QVariant& v, bool doChroot, std::chrono::seconds timeout )
     : CommandList( doChroot, timeout )
 {
-    if ( v.type() == QVariant::List )
+    if ( Calamares::typeOf( v ) == Calamares::ListVariantType )
     {
         const auto v_list = v.toList();
         if ( v_list.count() )
@@ -88,11 +130,11 @@ CommandList::CommandList::CommandList( const QVariant& v, bool doChroot, std::ch
             cWarning() << "Empty CommandList";
         }
     }
-    else if ( v.type() == QVariant::String )
+    else if ( Calamares::typeOf( v ) == Calamares::StringVariantType )
     {
-        append( v.toString() );
+        append( { v.toString(), m_timeout } );
     }
-    else if ( v.type() == QVariant::Map )
+    else if ( Calamares::typeOf( v ) == Calamares::MapVariantType )
     {
         auto c( get_variant_object( v.toMap() ) );
         if ( c.isValid() )
@@ -103,65 +145,32 @@ CommandList::CommandList::CommandList( const QVariant& v, bool doChroot, std::ch
     }
     else
     {
-        cWarning() << "CommandList does not understand variant" << v.type();
+        cWarning() << "CommandList does not understand variant" << Calamares::typeOf( v );
     }
 }
 
-CommandList::~CommandList() {}
-
-static inline bool
-findInCommands( const CommandList& l, const QString& needle )
-{
-    for ( CommandList::const_iterator i = l.cbegin(); i != l.cend(); ++i )
-        if ( i->command().contains( needle ) )
-        {
-            return true;
-        }
-    return false;
-}
-
 Calamares::JobResult
 CommandList::run()
 {
-    QLatin1String rootMagic( "@@ROOT@@" );
-    QLatin1String userMagic( "@@USER@@" );
-
     System::RunLocation location = m_doChroot ? System::RunLocation::RunInTarget : System::RunLocation::RunInHost;
 
-    /* Figure out the replacement for @@ROOT@@ */
-    QString root = QStringLiteral( "/" );
-    Calamares::GlobalStorage* gs = Calamares::JobQueue::instance()->globalStorage();
-
-    bool needsRootSubstitution = findInCommands( *this, rootMagic );
-    if ( needsRootSubstitution && ( location == System::RunLocation::RunInHost ) )
+    auto expander = get_gs_expander( location );
+    auto expandedList = expand( expander );
+    if ( expander.hasErrors() )
     {
-        if ( !gs || !gs->contains( "rootMountPoint" ) )
-        {
-            cError() << "No rootMountPoint defined.";
-            return Calamares::JobResult::error(
-                QCoreApplication::translate( "CommandList", "Could not run command." ),
-                QCoreApplication::translate( "CommandList",
-                                             "The command runs in the host environment and needs to know the root "
-                                             "path, but no rootMountPoint is defined." ) );
-        }
-        root = gs->value( "rootMountPoint" ).toString();
-    }
-
-    bool needsUserSubstitution = findInCommands( *this, userMagic );
-    if ( needsUserSubstitution && ( !gs || !gs->contains( "username" ) ) )
-    {
-        cError() << "No username defined.";
+        const auto missing = expander.errorNames();
+        cError() << "Missing variables:" << missing;
         return Calamares::JobResult::error(
             QCoreApplication::translate( "CommandList", "Could not run command." ),
             QCoreApplication::translate( "CommandList",
-                                         "The command needs to know the user's name, but no username is defined." ) );
+                                         "The commands use variables that are not defined. "
+                                         "Missing variables are: %1." )
+                .arg( missing.join( ',' ) ) );
     }
-    QString user = gs->value( "username" ).toString();  // may be blank if unset
 
-    for ( CommandList::const_iterator i = cbegin(); i != cend(); ++i )
+    for ( CommandList::const_iterator i = expandedList.cbegin(); i != expandedList.cend(); ++i )
     {
         QString processed_cmd = i->command();
-        processed_cmd.replace( rootMagic, root ).replace( userMagic, user );
         bool suppress_result = false;
         if ( processed_cmd.startsWith( '-' ) )
         {
@@ -191,10 +200,23 @@ CommandList::run()
     return Calamares::JobResult::ok();
 }
 
-void
-CommandList::append( const QString& s )
+CommandList
+CommandList::expand( KMacroExpanderBase& expander ) const
 {
-    append( CommandLine( s, m_timeout ) );
+    // Copy and expand the list, collecting missing variables (so don't call expand())
+    CommandList expandedList( m_doChroot, m_timeout );
+    std::transform( cbegin(),
+                    cend(),
+                    std::back_inserter( expandedList ),
+                    [ &expander ]( const CommandLine& c ) { return c.expand( expander ); } );
+    return expandedList;
 }
 
-}  // namespace CalamaresUtils
+CommandList
+CommandList::expand() const
+{
+    auto expander = get_gs_expander( System::RunLocation::RunInHost );
+    return expand( expander );
+}
+
+}  // namespace Calamares
