@@ -12,49 +12,46 @@
 #include "DummyCppJob.h"
 
 #include <QDateTime>
-#include <QProcess>
 #include <QThread>
 
 #include "CalamaresVersion.h"
 #include "GlobalStorage.h"
 #include "JobQueue.h"
 
-#include "utils/CalamaresUtilsSystem.h"
+#include "compat/Variant.h"
 #include "utils/Logger.h"
+#include "utils/System.h"
 
 DummyCppJob::DummyCppJob( QObject* parent )
     : Calamares::CppJob( parent )
 {
 }
 
-
 DummyCppJob::~DummyCppJob() {}
 
-
 QString
 DummyCppJob::prettyName() const
 {
-    return tr( "Dummy C++ Job" );
+    return tr( "Performing dummy C++ job…", "@status" );
 }
 
-
 static QString variantListToString( const QVariantList& variantList );
 static QString variantMapToString( const QVariantMap& variantMap );
 static QString variantHashToString( const QVariantHash& variantHash );
 
-
 static QString
 variantToString( const QVariant& variant )
 {
-    if ( variant.type() == QVariant::Map )
+    if ( Calamares::typeOf( variant ) == Calamares::MapVariantType )
     {
         return variantMapToString( variant.toMap() );
     }
-    else if ( variant.type() == QVariant::Hash )
+    else if ( Calamares::typeOf( variant ) == Calamares::HashVariantType )
     {
         return variantHashToString( variant.toHash() );
     }
-    else if ( ( variant.type() == QVariant::List ) || ( variant.type() == QVariant::StringList ) )
+    else if ( ( Calamares::typeOf( variant ) == Calamares::ListVariantType )
+              || ( Calamares::typeOf( variant ) == Calamares::StringListVariantType ) )
     {
         return variantListToString( variant.toList() );
     }
@@ -64,7 +61,6 @@ variantToString( const QVariant& variant )
     }
 }
 
-
 static QString
 variantListToString( const QVariantList& variantList )
 {
@@ -76,7 +72,6 @@ variantListToString( const QVariantList& variantList )
     return '{' + result.join( ',' ) + '}';
 }
 
-
 static QString
 variantMapToString( const QVariantMap& variantMap )
 {
@@ -88,7 +83,6 @@ variantMapToString( const QVariantMap& variantMap )
     return '[' + result.join( ',' ) + ']';
 }
 
-
 static QString
 variantHashToString( const QVariantHash& variantHash )
 {
@@ -100,15 +94,14 @@ variantHashToString( const QVariantHash& variantHash )
     return '<' + result.join( ',' ) + '>';
 }
 
-
 Calamares::JobResult
 DummyCppJob::exec()
 {
     // Ported from dummypython
-    CalamaresUtils::System::runCommand( CalamaresUtils::System::RunLocation::RunInHost,
-                                        QStringList() << "/bin/sh"
-                                                      << "-c"
-                                                      << "touch ~/calamares-dummycpp" );
+    Calamares::System::runCommand( Calamares::System::RunLocation::RunInHost,
+                                   QStringList() << "/bin/sh"
+                                                 << "-c"
+                                                 << "touch ~/calamares-dummycpp" );
     QString accumulator = QDateTime::currentDateTimeUtc().toString( Qt::ISODate ) + '\n';
     accumulator += QStringLiteral( "Calamares version: " ) + CALAMARES_VERSION_SHORT + '\n';
     accumulator += QStringLiteral( "This job's name: " ) + prettyName() + '\n';
@@ -140,7 +133,6 @@ DummyCppJob::exec()
     return Calamares::JobResult::ok();
 }
 
-
 void
 DummyCppJob::setConfigurationMap( const QVariantMap& configurationMap )
 {
