@@ -40,6 +40,7 @@
 static QStringList
 loadLocales( const QString& localeGenPath )
 {
+    Logger::Once o;
     QStringList localeGenLines;
 
     // Some distros come with a meaningfully commented and easy to parse locale.gen,
@@ -52,6 +53,7 @@ loadLocales( const QString& localeGenPath )
 
     if ( supported.exists() && supported.open( QIODevice::ReadOnly | QIODevice::Text ) )
     {
+        cDebug() << o << "Loading locales from" << supported.fileName();
         ba = supported.readAll();
         supported.close();
 
@@ -66,6 +68,7 @@ loadLocales( const QString& localeGenPath )
         QFile localeGen( localeGenPath );
         if ( localeGen.open( QIODevice::ReadOnly | QIODevice::Text ) )
         {
+            cDebug() << o << "Loading locales from" << localeGenPath;
             ba = localeGen.readAll();
             localeGen.close();
         }
@@ -115,6 +118,10 @@ loadLocales( const QString& localeGenPath )
                    << "* a complete pre-compiled locale-gen database which allows complete locale -a output.";
         return localeGenLines;  // something went wrong and there's nothing we can do about it.
     }
+    else
+    {
+        cDebug() << o << "Read" << localeGenLines.length() << "lines";
+    }
 
     // Assuming we have a list of supported locales, we usually only want UTF-8 ones
     // because it's not 1995.
@@ -134,12 +141,13 @@ loadLocales( const QString& localeGenPath )
         s = s.simplified();
     };
     std::for_each( localeGenLines.begin(), localeGenLines.end(), unredundant );
+    cDebug() << o << "After filtering" << localeGenLines.length() << "lines";
 
     return localeGenLines;
 }
 
 static bool
-updateGSLocation( Calamares::GlobalStorage* gs, const CalamaresUtils::Locale::TimeZoneData* location )
+updateGSLocation( Calamares::GlobalStorage* gs, const Calamares::Locale::TimeZoneData* location )
 {
     const QString regionKey = QStringLiteral( "locationRegion" );
     const QString zoneKey = QStringLiteral( "locationZone" );
@@ -168,14 +176,14 @@ updateGSLocation( Calamares::GlobalStorage* gs, const CalamaresUtils::Locale::Ti
 static void
 updateGSLocale( Calamares::GlobalStorage* gs, const LocaleConfiguration& locale )
 {
-    CalamaresUtils::Locale::insertGS( *gs, locale.toMap(), CalamaresUtils::Locale::InsertMode::Overwrite );
+    Calamares::Locale::insertGS( *gs, locale.toMap(), Calamares::Locale::InsertMode::Overwrite );
 }
 
 Config::Config( QObject* parent )
     : QObject( parent )
-    , m_regionModel( std::make_unique< CalamaresUtils::Locale::RegionsModel >() )
-    , m_zonesModel( std::make_unique< CalamaresUtils::Locale::ZonesModel >() )
-    , m_regionalZonesModel( std::make_unique< CalamaresUtils::Locale::RegionalZonesModel >( m_zonesModel.get() ) )
+    , m_regionModel( std::make_unique< Calamares::Locale::RegionsModel >() )
+    , m_zonesModel( std::make_unique< Calamares::Locale::ZonesModel >() )
+    , m_regionalZonesModel( std::make_unique< Calamares::Locale::RegionalZonesModel >( m_zonesModel.get() ) )
 {
     // Slightly unusual: connect to our *own* signals. Wherever the language
     // or the location is changed, these signals are emitted, so hook up to
@@ -237,7 +245,7 @@ Config::setCurrentLocation()
 void
 Config::setCurrentLocation( const QString& regionzone )
 {
-    auto r = CalamaresUtils::GeoIP::splitTZString( regionzone );
+    auto r = Calamares::GeoIP::splitTZString( regionzone );
     if ( r.isValid() )
     {
         setCurrentLocation( r.first, r.second );
@@ -247,7 +255,7 @@ Config::setCurrentLocation( const QString& regionzone )
 void
 Config::setCurrentLocation( const QString& regionName, const QString& zoneName )
 {
-    using namespace CalamaresUtils::Locale;
+    using namespace Calamares::Locale;
     auto* zone = m_zonesModel->find( regionName, zoneName );
     if ( zone )
     {
@@ -261,7 +269,7 @@ Config::setCurrentLocation( const QString& regionName, const QString& zoneName )
 }
 
 void
-Config::setCurrentLocation( const CalamaresUtils::Locale::TimeZoneData* location )
+Config::setCurrentLocation( const Calamares::Locale::TimeZoneData* location )
 {
     const bool updateLocation = ( location != m_currentLocation );
     if ( updateLocation )
@@ -305,8 +313,14 @@ Config::automaticLocaleConfiguration() const
     {
         return LocaleConfiguration();
     }
-    return LocaleConfiguration::fromLanguageAndLocation(
-        QLocale().name(), supportedLocales(), currentLocation()->country() );
+
+    auto* gs = Calamares::JobQueue::instance()->globalStorage();
+    QString lang = Calamares::Locale::readGS( *gs, QStringLiteral( "LANG" ) );
+    if ( lang.isEmpty() )
+    {
+        lang = QLocale().name();
+    }
+    return LocaleConfiguration::fromLanguageAndLocation( lang, supportedLocales(), currentLocation()->country() );
 }
 
 LocaleConfiguration
@@ -356,7 +370,7 @@ Config::setLCLocaleExplicitly( const QString& locale )
 QString
 Config::currentLocationStatus() const
 {
-    return tr( "Set timezone to %1/%2." )
+    return tr( "Set timezone to %1/%2", "@action" )
         .arg( m_currentLocation ? m_currentLocation->region() : QString(),
               m_currentLocation ? m_currentLocation->zone() : QString() );
 }
@@ -381,11 +395,10 @@ Config::currentTimezoneName() const
     return QString();
 }
 
-
 static inline QString
 localeLabel( const QString& s )
 {
-    using CalamaresUtils::Locale::Translation;
+    using Calamares::Locale::Translation;
 
     Translation lang( { s }, Translation::LabelFormat::AlwaysWithCountry );
     return lang.label();
@@ -394,14 +407,14 @@ localeLabel( const QString& s )
 QString
 Config::currentLanguageStatus() const
 {
-    return tr( "The system language will be set to %1." )
+    return tr( "The system language will be set to %1", "@info" )
         .arg( localeLabel( m_selectedLocaleConfiguration.language() ) );
 }
 
 QString
 Config::currentLCStatus() const
 {
-    return tr( "The numbers and dates locale will be set to %1." )
+    return tr( "The numbers and dates locale will be set to %1", "@info" )
         .arg( localeLabel( m_selectedLocaleConfiguration.lc_numeric ) );
 }
 
@@ -415,7 +428,7 @@ Config::prettyStatus() const
 static inline void
 getLocaleGenLines( const QVariantMap& configurationMap, QStringList& localeGenLines )
 {
-    QString localeGenPath = CalamaresUtils::getString( configurationMap, "localeGenPath" );
+    QString localeGenPath = Calamares::getString( configurationMap, "localeGenPath" );
     if ( localeGenPath.isEmpty() )
     {
         localeGenPath = QStringLiteral( "/etc/locale.gen" );
@@ -426,8 +439,8 @@ getLocaleGenLines( const QVariantMap& configurationMap, QStringList& localeGenLi
 static inline void
 getAdjustLiveTimezone( const QVariantMap& configurationMap, bool& adjustLiveTimezone )
 {
-    adjustLiveTimezone = CalamaresUtils::getBool(
-        configurationMap, "adjustLiveTimezone", Calamares::Settings::instance()->doChroot() );
+    adjustLiveTimezone
+        = Calamares::getBool( configurationMap, "adjustLiveTimezone", Calamares::Settings::instance()->doChroot() );
 #ifdef DEBUG_TIMEZONES
     if ( adjustLiveTimezone )
     {
@@ -445,23 +458,23 @@ getAdjustLiveTimezone( const QVariantMap& configurationMap, bool& adjustLiveTime
 }
 
 static inline void
-getStartingTimezone( const QVariantMap& configurationMap, CalamaresUtils::GeoIP::RegionZonePair& startingTimezone )
+getStartingTimezone( const QVariantMap& configurationMap, Calamares::GeoIP::RegionZonePair& startingTimezone )
 {
-    QString region = CalamaresUtils::getString( configurationMap, "region" );
-    QString zone = CalamaresUtils::getString( configurationMap, "zone" );
+    QString region = Calamares::getString( configurationMap, "region" );
+    QString zone = Calamares::getString( configurationMap, "zone" );
     if ( !region.isEmpty() && !zone.isEmpty() )
     {
-        startingTimezone = CalamaresUtils::GeoIP::RegionZonePair( region, zone );
+        startingTimezone = Calamares::GeoIP::RegionZonePair( region, zone );
     }
     else
     {
         startingTimezone
-            = CalamaresUtils::GeoIP::RegionZonePair( QStringLiteral( "America" ), QStringLiteral( "New_York" ) );
+            = Calamares::GeoIP::RegionZonePair( QStringLiteral( "America" ), QStringLiteral( "New_York" ) );
     }
 
-    if ( CalamaresUtils::getBool( configurationMap, "useSystemTimezone", false ) )
+    if ( Calamares::getBool( configurationMap, "useSystemTimezone", false ) )
     {
-        auto systemtz = CalamaresUtils::GeoIP::splitTZString( QTimeZone::systemTimeZoneId() );
+        auto systemtz = Calamares::GeoIP::splitTZString( QTimeZone::systemTimeZoneId() );
         if ( systemtz.isValid() )
         {
             cDebug() << "Overriding configured timezone" << startingTimezone << "with system timezone" << systemtz;
@@ -471,17 +484,17 @@ getStartingTimezone( const QVariantMap& configurationMap, CalamaresUtils::GeoIP:
 }
 
 static inline void
-getGeoIP( const QVariantMap& configurationMap, std::unique_ptr< CalamaresUtils::GeoIP::Handler >& geoip )
+getGeoIP( const QVariantMap& configurationMap, std::unique_ptr< Calamares::GeoIP::Handler >& geoip )
 {
     bool ok = false;
-    QVariantMap map = CalamaresUtils::getSubMap( configurationMap, "geoip", ok );
+    QVariantMap map = Calamares::getSubMap( configurationMap, "geoip", ok );
     if ( ok )
     {
-        QString url = CalamaresUtils::getString( map, "url" );
-        QString style = CalamaresUtils::getString( map, "style" );
-        QString selector = CalamaresUtils::getString( map, "selector" );
+        QString url = Calamares::getString( map, "url" );
+        QString style = Calamares::getString( map, "style" );
+        QString selector = Calamares::getString( map, "selector" );
 
-        geoip = std::make_unique< CalamaresUtils::GeoIP::Handler >( style, url, selector );
+        geoip = std::make_unique< Calamares::GeoIP::Handler >( style, url, selector );
         if ( !geoip->isValid() )
         {
             cWarning() << "GeoIP Style" << style << "is not recognized.";
@@ -529,16 +542,15 @@ Config::finalizeGlobalStorage() const
     updateGSLocation( gs, currentLocation() );
 }
 
-
 void
 Config::startGeoIP()
 {
     if ( m_geoip && m_geoip->isValid() )
     {
-        auto& network = CalamaresUtils::Network::Manager::instance();
+        Calamares::Network::Manager network;
         if ( network.hasInternet() || network.synchronousPing( m_geoip->url() ) )
         {
-            using Watcher = QFutureWatcher< CalamaresUtils::GeoIP::RegionZonePair >;
+            using Watcher = QFutureWatcher< Calamares::GeoIP::RegionZonePair >;
             m_geoipWatcher = std::make_unique< Watcher >();
             m_geoipWatcher->setFuture( m_geoip->query() );
             connect( m_geoipWatcher.get(), &Watcher::finished, this, &Config::completeGeoIP );
