@@ -13,8 +13,9 @@
 #include "MachineIdJob.h"
 #include "Workers.h"
 
-#include "utils/CalamaresUtilsSystem.h"
 #include "utils/Logger.h"
+#include "utils/NamedEnum.h"
+#include "utils/System.h"
 #include "utils/Variant.h"
 
 #include "GlobalStorage.h"
@@ -22,15 +23,32 @@
 
 #include <QFile>
 
+const NamedEnumTable< MachineId::SystemdMachineIdStyle >&
+styleNames()
+{
+    using T = MachineId::SystemdMachineIdStyle;
+    // *INDENT-OFF*
+    // clang-format off
+    static const NamedEnumTable< MachineId::SystemdMachineIdStyle > names {
+        { QStringLiteral( "none" ), T::Blank },
+        { QStringLiteral( "blank" ), T::Blank },
+        { QStringLiteral( "uuid" ), T::Uuid },
+        { QStringLiteral( "systemd" ), T::Uuid },
+        { QStringLiteral( "literal-uninitialized" ), T::Uninitialized },
+    };
+    // clang-format on
+    // *INDENT-ON*
+
+    return names;
+}
+
 MachineIdJob::MachineIdJob( QObject* parent )
     : Calamares::CppJob( parent )
 {
 }
 
-
 MachineIdJob::~MachineIdJob() {}
 
-
 QString
 MachineIdJob::prettyName() const
 {
@@ -58,7 +76,7 @@ MachineIdJob::exec()
     QString target_systemd_machineid_file = QStringLiteral( "/etc/machine-id" );
     QString target_dbus_machineid_file = QStringLiteral( "/var/lib/dbus/machine-id" );
 
-    const CalamaresUtils::System* system = CalamaresUtils::System::instance();
+    const Calamares::System* system = Calamares::System::instance();
 
     // Clear existing files
     for ( const auto& entropy_file : m_entropy_files )
@@ -77,7 +95,7 @@ MachineIdJob::exec()
     //Create new files
     for ( const auto& entropy_file : m_entropy_files )
     {
-        if ( !CalamaresUtils::System::instance()->createTargetParentDirs( entropy_file ) )
+        if ( !Calamares::System::instance()->createTargetParentDirs( entropy_file ) )
         {
             return Calamares::JobResult::error(
                 QObject::tr( "Directory not found" ),
@@ -98,7 +116,7 @@ MachineIdJob::exec()
         {
             cWarning() << "Could not create systemd data-directory.";
         }
-        auto r = MachineId::createSystemdMachineId( root, target_systemd_machineid_file );
+        auto r = MachineId::createSystemdMachineId( m_systemd_style, root, target_systemd_machineid_file );
         if ( !r )
         {
             return r;
@@ -131,20 +149,25 @@ MachineIdJob::exec()
     return Calamares::JobResult::ok();
 }
 
-
 void
 MachineIdJob::setConfigurationMap( const QVariantMap& map )
 {
-    m_systemd = CalamaresUtils::getBool( map, "systemd", false );
+    m_systemd = Calamares::getBool( map, "systemd", false );
 
-    m_dbus = CalamaresUtils::getBool( map, "dbus", false );
+    const auto style = Calamares::getString( map, "systemd-style", QString() );
+    if ( !style.isEmpty() )
+    {
+        m_systemd_style = styleNames().find( style, MachineId::SystemdMachineIdStyle::Uuid );
+    }
+
+    m_dbus = Calamares::getBool( map, "dbus", false );
     if ( map.contains( "dbus-symlink" ) )
     {
-        m_dbus_symlink = CalamaresUtils::getBool( map, "dbus-symlink", false );
+        m_dbus_symlink = Calamares::getBool( map, "dbus-symlink", false );
     }
     else if ( map.contains( "symlink" ) )
     {
-        m_dbus_symlink = CalamaresUtils::getBool( map, "symlink", false );
+        m_dbus_symlink = Calamares::getBool( map, "symlink", false );
         cWarning() << "MachineId: configuration setting *symlink* is deprecated, use *dbus-symlink*.";
     }
     // else it's still false from the constructor
@@ -152,9 +175,9 @@ MachineIdJob::setConfigurationMap( const QVariantMap& map )
     // ignore it, though, if dbus is false
     m_dbus_symlink = m_dbus && m_dbus_symlink;
 
-    m_entropy_copy = CalamaresUtils::getBool( map, "entropy-copy", false );
-    m_entropy_files = CalamaresUtils::getStringList( map, "entropy-files" );
-    if ( CalamaresUtils::getBool( map, "entropy", false ) )
+    m_entropy_copy = Calamares::getBool( map, "entropy-copy", false );
+    m_entropy_files = Calamares::getStringList( map, "entropy-files" );
+    if ( Calamares::getBool( map, "entropy", false ) )
     {
         cWarning() << "MachineId:: configuration setting *entropy* is deprecated, use *entropy-files* instead.";
         m_entropy_files.append( QStringLiteral( "/var/lib/urandom/random-seed" ) );
