@@ -9,10 +9,10 @@
 
 #include "Tests.h"
 
-#ifdef HAVE_XML
+#ifdef HAVE_APPDATA
 #include "ItemAppData.h"
 #endif
-#ifdef HAVE_APPSTREAM
+#ifdef HAVE_APPSTREAM_VERSION
 #include "ItemAppStream.h"
 #endif
 #include "PackageModel.h"
