@@ -25,7 +25,7 @@
 #include "Branding.h"
 #include "GlobalStorage.h"
 #include "JobQueue.h"
-#include "utils/CalamaresUtilsGui.h"
+#include "utils/Gui.h"
 #include "utils/Logger.h"
 #include "utils/QtCompat.h"
 #include "utils/Retranslator.h"
@@ -59,7 +59,6 @@ PartitionViewStep::PartitionViewStep( QObject* parent )
     // We're not done loading, but we need the configuration map first.
 }
 
-
 void
 PartitionViewStep::initPartitionCoreModule()
 {
@@ -67,7 +66,6 @@ PartitionViewStep::initPartitionCoreModule()
     m_core->init();
 }
 
-
 void
 PartitionViewStep::continueLoading()
 {
@@ -90,7 +88,6 @@ PartitionViewStep::continueLoading()
     connect( m_choicePage, &ChoicePage::nextStatusChanged, this, &PartitionViewStep::nextPossiblyChanged );
 }
 
-
 PartitionViewStep::~PartitionViewStep()
 {
     if ( m_choicePage && m_choicePage->parent() == nullptr )
@@ -104,7 +101,6 @@ PartitionViewStep::~PartitionViewStep()
     delete m_core;
 }
 
-
 QString
 PartitionViewStep::prettyName() const
 {
@@ -233,31 +229,31 @@ PartitionViewStep::createSummaryWidget() const
     QWidget* widget = new QWidget;
     QVBoxLayout* mainLayout = new QVBoxLayout;
     widget->setLayout( mainLayout );
-    mainLayout->setMargin( 0 );
+    Calamares::unmarginLayout( mainLayout );
 
     Config::InstallChoice choice = m_config->installChoice();
 
     QFormLayout* formLayout = new QFormLayout( widget );
-    const int MARGIN = CalamaresUtils::defaultFontHeight() / 2;
+    const int MARGIN = Calamares::defaultFontHeight() / 2;
     formLayout->setContentsMargins( MARGIN, 0, MARGIN, MARGIN );
     mainLayout->addLayout( formLayout );
 
 #if defined( DEBUG_PARTITION_UNSAFE ) || defined( DEBUG_PARTITION_BAIL_OUT ) || defined( DEBUG_PARTITION_SKIP )
-    auto specialRow = [ = ]( CalamaresUtils::ImageType t, const QString& s )
+    auto specialRow = [ = ]( Calamares::ImageType t, const QString& s )
     {
         QLabel* icon = new QLabel;
-        icon->setPixmap( CalamaresUtils::defaultPixmap( t ) );
+        icon->setPixmap( Calamares::defaultPixmap( t ) );
         formLayout->addRow( icon, new QLabel( s ) );
     };
 #endif
 #if defined( DEBUG_PARTITION_UNSAFE )
-    specialRow( CalamaresUtils::ImageType::StatusWarning, tr( "Unsafe partition actions are enabled." ) );
+    specialRow( Calamares::ImageType::StatusWarning, tr( "Unsafe partition actions are enabled." ) );
 #endif
 #if defined( DEBUG_PARTITION_BAIL_OUT )
-    specialRow( CalamaresUtils::ImageType::Information, tr( "Partitioning is configured to <b>always</b> fail." ) );
+    specialRow( Calamares::ImageType::Information, tr( "Partitioning is configured to <b>always</b> fail." ) );
 #endif
 #if defined( DEBUG_PARTITION_SKIP )
-    specialRow( CalamaresUtils::ImageType::Information, tr( "No partitions will be changed." ) );
+    specialRow( Calamares::ImageType::Information, tr( "No partitions will be changed." ) );
 #endif
 
     const QList< PartitionCoreModule::SummaryInfo > list = m_core->createSummaryInfo();
@@ -293,7 +289,7 @@ PartitionViewStep::createSummaryWidget() const
         previewLabels->setSelectionMode( QAbstractItemView::NoSelection );
         info.partitionModelBefore->setParent( widget );
         field = new QVBoxLayout;
-        CalamaresUtils::unmarginLayout( field );
+        Calamares::unmarginLayout( field );
         field->setSpacing( 6 );
         field->addWidget( preview );
         field->addWidget( previewLabels );
@@ -311,7 +307,7 @@ PartitionViewStep::createSummaryWidget() const
             Calamares::Branding::instance()->string( Calamares::Branding::BootloaderEntryName ) );
         info.partitionModelAfter->setParent( widget );
         field = new QVBoxLayout;
-        CalamaresUtils::unmarginLayout( field );
+        Calamares::unmarginLayout( field );
         field->setSpacing( 6 );
         field->addWidget( preview );
         field->addWidget( previewLabels );
@@ -323,7 +319,7 @@ PartitionViewStep::createSummaryWidget() const
         QLabel* jobsLabel = new QLabel( widget );
         mainLayout->addWidget( jobsLabel );
         jobsLabel->setText( jobsLines.join( "<br/>" ) );
-        jobsLabel->setMargin( CalamaresUtils::defaultFontHeight() / 2 );
+        jobsLabel->setMargin( Calamares::defaultFontHeight() / 2 );
         QPalette pal;
         pal.setColor( WindowBackground, pal.window().color().lighter( 108 ) );
         jobsLabel->setAutoFillBackground( true );
@@ -362,7 +358,6 @@ PartitionViewStep::next()
     }
 }
 
-
 void
 PartitionViewStep::back()
 {
@@ -379,7 +374,6 @@ PartitionViewStep::back()
     }
 }
 
-
 bool
 PartitionViewStep::isNextEnabled() const
 {
@@ -408,7 +402,6 @@ PartitionViewStep::isBackEnabled() const
     return true;
 }
 
-
 bool
 PartitionViewStep::isAtBeginning() const
 {
@@ -419,7 +412,6 @@ PartitionViewStep::isAtBeginning() const
     return true;
 }
 
-
 bool
 PartitionViewStep::isAtEnd() const
 {
@@ -436,7 +428,6 @@ PartitionViewStep::isAtEnd() const
     return true;
 }
 
-
 void
 PartitionViewStep::onActivate()
 {
@@ -447,7 +438,6 @@ PartitionViewStep::onActivate()
     {
         m_choicePage->applyActionChoice( Config::InstallChoice::Alongside );
         //        m_choicePage->reset();
-        //FIXME: ReplaceWidget should be reset maybe?
     }
 }
 
@@ -472,7 +462,7 @@ shouldWarnForGPTOnBIOS( const PartitionCoreModule* core )
             // So this is a BIOS system, and the bootloader will be installed on a GPT system
             for ( const auto& partition : qAsConst( table->children() ) )
             {
-                using CalamaresUtils::Units::operator""_MiB;
+                using Calamares::Units::operator""_MiB;
                 if ( ( partition->activeFlags() & KPM_PARTITION_FLAG( BiosGrub ) )
                      && ( partition->fileSystem().type() == FileSystem::Unformatted )
                      && ( partition->capacity() >= 8_MiB ) )
@@ -492,6 +482,27 @@ shouldWarnForGPTOnBIOS( const PartitionCoreModule* core )
     return true;
 }
 
+static bool
+shouldWarnForNotEncryptedBoot( const Config* config, const PartitionCoreModule* core )
+{
+    if ( config->showNotEncryptedBootMessage() )
+    {
+        Partition* root_p = core->findPartitionByMountPoint( "/" );
+        Partition* boot_p = core->findPartitionByMountPoint( "/boot" );
+
+        if ( root_p and boot_p )
+        {
+            if ( ( root_p->fileSystem().type() == FileSystem::Luks && boot_p->fileSystem().type() != FileSystem::Luks )
+                 || ( root_p->fileSystem().type() == FileSystem::Luks2
+                      && boot_p->fileSystem().type() != FileSystem::Luks2 ) )
+            {
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
 void
 PartitionViewStep::onLeave()
 {
@@ -508,11 +519,6 @@ PartitionViewStep::onLeave()
         {
             const QString espMountPoint
                 = Calamares::JobQueue::instance()->globalStorage()->value( "efiSystemPartition" ).toString();
-#ifdef WITH_KPMCORE4API
-            const auto espFlag = PartitionTable::Flag::Boot;
-#else
-            const auto espFlag = PartitionTable::FlagEsp;
-#endif
             Partition* esp = m_core->findPartitionByMountPoint( espMountPoint );
 
             QString message;
@@ -521,60 +527,88 @@ PartitionViewStep::onLeave()
             Logger::Once o;
 
             const bool okType = esp && PartUtils::isEfiFilesystemSuitableType( esp );
-            const bool okSize = esp && PartUtils::isEfiFilesystemSuitableSize( esp );
+            const bool okRecommendedSize = esp && PartUtils::isEfiFilesystemRecommendedSize( esp );
+            const bool okMinimumSize = esp && PartUtils::isEfiFilesystemMinimumSize( esp );
             const bool okFlag = esp && PartUtils::isEfiBootable( esp );
 
-            if ( !esp )
-            {
-                message = tr( "No EFI system partition configured" );
-            }
-            else if ( !( okType && okSize && okFlag ) )
-            {
-                message = tr( "EFI system partition configured incorrectly" );
-            }
+            const bool espExistsButIsWrong = esp && !( okType && okMinimumSize && okFlag );
+
+            const QString genericWrongnessMessage = tr( "An EFI system partition is necessary to start %1."
+                                                        "<br/><br/>"
+                                                        "To configure an EFI system partition, go back and "
+                                                        "select or create a suitable filesystem." )
+                                                        .arg( branding->shortProductName() );
+            const QString genericRecommendationMessage
+                = tr( "An EFI system partition is necessary to start %1."
+                      "<br/><br/>"
+                      "The EFI system partition does not meet recommendations. It is "
+                      "recommended to go back and "
+                      "select or create a suitable filesystem." )
+                      .arg( branding->shortProductName() );
+
+            const QString wrongMountPointMessage
+                = tr( "The filesystem must be mounted on <strong>%1</strong>." ).arg( espMountPoint );
+            const QString wrongTypeMessage = tr( "The filesystem must have type FAT32." );
+            const QString wrongFlagMessage = tr( "The filesystem must have flag <strong>%1</strong> set." )
+                                                 .arg( PartitionTable::flagName( PartitionTable::Flag::Boot ) );
+
+            const auto recommendedMiB = Calamares::BytesToMiB( PartUtils::efiFilesystemRecommendedSize() );
+            const auto minimumMiB = Calamares::BytesToMiB( PartUtils::efiFilesystemMinimumSize() );
+
+            // Three flavors of size-is-wrong
+            const QString requireConfiguredSize
+                = tr( "The filesystem must be at least %1 MiB in size." ).arg( recommendedMiB );
+            const QString requiredMinimumSize
+                = tr( "The filesystem must be at least %1 MiB in size." ).arg( minimumMiB );
+            const QString suggestConfiguredSize
+                = tr( "The minimum recommended size for the filesystem is %1 MiB." ).arg( recommendedMiB );
+
+            const QString mayFail = tr( "You can continue without setting up an EFI system "
+                                        "partition but your system may fail to start." );
+            const QString possibleFail = tr( "You can continue with this EFI system "
+                                             "partition configuration but your system may fail to start." );
+
+            const QString startList = QStringLiteral( "<br/><br/><ul>" );
+            const QString endList = QStringLiteral( "</ul><br/><br/>" );
+
+            auto listItem = []( QString s ) -> QString
+            { return s.prepend( QStringLiteral( "<li>" ) ).append( QStringLiteral( "</li>" ) ); };
 
-            if ( !esp || !( okType && okSize && okFlag ) )
-            {
-                description = tr( "An EFI system partition is necessary to start %1."
-                                  "<br/><br/>"
-                                  "To configure an EFI system partition, go back and "
-                                  "select or create a suitable filesystem." )
-                                  .arg( branding->shortProductName() );
-            }
             if ( !esp )
             {
                 cDebug() << o << "No ESP mounted";
-                description.append( ' ' );
-                description.append(
-                    tr( "The filesystem must be mounted on <strong>%1</strong>." ).arg( espMountPoint ) );
+                message = tr( "No EFI system partition configured" );
+
+                description = genericWrongnessMessage + startList + listItem( wrongMountPointMessage )
+                    + listItem( requireConfiguredSize ) + listItem( wrongTypeMessage ) + listItem( wrongFlagMessage )
+                    + endList + mayFail;
             }
-            if ( !okType )
+            else if ( espExistsButIsWrong )
             {
-                cDebug() << o << "ESP wrong type";
-                description.append( ' ' );
-                description.append( tr( "The filesystem must have type FAT32." ) );
+                message = tr( "EFI system partition configured incorrectly" );
+
+                description = genericWrongnessMessage + startList;
+                if ( !okMinimumSize )
+                {
+                    description.append( listItem( requiredMinimumSize ) );
+                }
+                if ( !okType )
+                {
+                    description.append( listItem( wrongTypeMessage ) );
+                }
+                if ( !okFlag )
+                {
+                    description.append( listItem( wrongFlagMessage ) );
+                }
+                description.append( endList );
+                description.append( mayFail );
             }
-            if ( !okSize )
+            else if ( !okRecommendedSize )
             {
-                cDebug() << o << "ESP too small";
-                const qint64 atLeastBytes = static_cast< qint64 >( PartUtils::efiFilesystemMinimumSize() );
-                const auto atLeastMiB = CalamaresUtils::BytesToMiB( atLeastBytes );
-                description.append( ' ' );
-                description.append( tr( "The filesystem must be at least %1 MiB in size." ).arg( atLeastMiB ) );
-            }
-            if ( !okFlag )
-            {
-                cDebug() << o << "ESP missing flag";
-                description.append( ' ' );
-                description.append( tr( "The filesystem must have flag <strong>%1</strong> set." )
-                                        .arg( PartitionTable::flagName( espFlag ) ) );
-            }
-            if ( !description.isEmpty() )
-            {
-                description.append( "<br/><br/>" );
-                description.append( tr( "You can continue without setting up an EFI system "
-                                        "partition but your system may fail to start." ) );
+                message = tr( "EFI system partition recommendation" );
+                description = genericRecommendationMessage + suggestConfiguredSize + possibleFail;
             }
+
             if ( !message.isEmpty() )
             {
                 QMessageBox mb( QMessageBox::Warning, message, description, QMessageBox::Ok, m_manualPartitionPage );
@@ -611,41 +645,29 @@ PartitionViewStep::onLeave()
             }
         }
 
-        Partition* root_p = m_core->findPartitionByMountPoint( "/" );
-        Partition* boot_p = m_core->findPartitionByMountPoint( "/boot" );
-
-        if ( root_p and boot_p )
+        if ( shouldWarnForNotEncryptedBoot( m_config, m_core ) )
         {
-            QString message;
-            QString description;
+            QString message = tr( "Boot partition not encrypted" );
+            QString description = tr( "A separate boot partition was set up together with "
+                                      "an encrypted root partition, but the boot partition "
+                                      "is not encrypted."
+                                      "<br/><br/>"
+                                      "There are security concerns with this kind of "
+                                      "setup, because important system files are kept "
+                                      "on an unencrypted partition.<br/>"
+                                      "You may continue if you wish, but filesystem "
+                                      "unlocking will happen later during system startup."
+                                      "<br/>To encrypt the boot partition, go back and "
+                                      "recreate it, selecting <strong>Encrypt</strong> "
+                                      "in the partition creation window." );
 
-            // If the root partition is encrypted, and there's a separate boot
-            // partition which is not encrypted
-            if ( root_p->fileSystem().type() == FileSystem::Luks && boot_p->fileSystem().type() != FileSystem::Luks )
-            {
-                message = tr( "Boot partition not encrypted" );
-                description = tr( "A separate boot partition was set up together with "
-                                  "an encrypted root partition, but the boot partition "
-                                  "is not encrypted."
-                                  "<br/><br/>"
-                                  "There are security concerns with this kind of "
-                                  "setup, because important system files are kept "
-                                  "on an unencrypted partition.<br/>"
-                                  "You may continue if you wish, but filesystem "
-                                  "unlocking will happen later during system startup."
-                                  "<br/>To encrypt the boot partition, go back and "
-                                  "recreate it, selecting <strong>Encrypt</strong> "
-                                  "in the partition creation window." );
-
-                QMessageBox mb( QMessageBox::Warning, message, description, QMessageBox::Ok, m_manualPartitionPage );
-                Calamares::fixButtonLabels( &mb );
-                mb.exec();
-            }
+            QMessageBox mb( QMessageBox::Warning, message, description, QMessageBox::Ok, m_manualPartitionPage );
+            Calamares::fixButtonLabels( &mb );
+            mb.exec();
         }
     }
 }
 
-
 void
 PartitionViewStep::setConfigurationMap( const QVariantMap& configurationMap )
 {
@@ -658,18 +680,18 @@ PartitionViewStep::setConfigurationMap( const QVariantMap& configurationMap )
     // Read and parse key swapPartitionName
     if ( configurationMap.contains( "swapPartitionName" ) )
     {
-        gs->insert( "swapPartitionName", CalamaresUtils::getString( configurationMap, "swapPartitionName" ) );
+        gs->insert( "swapPartitionName", Calamares::getString( configurationMap, "swapPartitionName" ) );
     }
 
     // OTHER SETTINGS
     //
-    gs->insert( "drawNestedPartitions", CalamaresUtils::getBool( configurationMap, "drawNestedPartitions", false ) );
+    gs->insert( "drawNestedPartitions", Calamares::getBool( configurationMap, "drawNestedPartitions", false ) );
     gs->insert( "alwaysShowPartitionLabels",
-                CalamaresUtils::getBool( configurationMap, "alwaysShowPartitionLabels", true ) );
+                Calamares::getBool( configurationMap, "alwaysShowPartitionLabels", true ) );
     gs->insert( "enableLuksAutomatedPartitioning",
-                CalamaresUtils::getBool( configurationMap, "enableLuksAutomatedPartitioning", true ) );
+                Calamares::getBool( configurationMap, "enableLuksAutomatedPartitioning", true ) );
 
-    QString partitionTableName = CalamaresUtils::getString( configurationMap, "defaultPartitionTableType" );
+    QString partitionTableName = Calamares::getString( configurationMap, "defaultPartitionTableType" );
     if ( partitionTableName.isEmpty() )
     {
         cWarning() << "Partition-module setting *defaultPartitionTableType* is unset, "
@@ -691,13 +713,16 @@ PartitionViewStep::setConfigurationMap( const QVariantMap& configurationMap )
                  this->m_future = nullptr;
              } );
 
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     QFuture< void > future = QtConcurrent::run( this, &PartitionViewStep::initPartitionCoreModule );
+#else
+    QFuture< void > future = QtConcurrent::run( &PartitionViewStep::initPartitionCoreModule, this );
+#endif
     m_future->setFuture( future );
 
     m_core->partitionLayout().init( m_config->defaultFsType(), configurationMap.value( "partitionLayout" ).toList() );
 }
 
-
 Calamares::JobList
 PartitionViewStep::jobs() const
 {
@@ -728,5 +753,4 @@ PartitionViewStep::checkRequirements()
     return l;
 }
 
-
 CALAMARES_PLUGIN_FACTORY_DEFINITION( PartitionViewStepFactory, registerPlugin< PartitionViewStep >(); )
