@@ -12,6 +12,7 @@
 #ifndef PARTITIONCOREMODULE_H
 #define PARTITIONCOREMODULE_H
 
+#include "Config.h"
 #include "core/KPMHelpers.h"
 #include "core/PartitionLayout.h"
 #include "core/PartitionModel.h"
@@ -84,6 +85,8 @@ public:
         PartitionModel* partitionModelAfter;
     };
 
+    struct DeviceInfo;
+
     PartitionCoreModule( QObject* parent = nullptr );
     ~PartitionCoreModule() override;
 
@@ -158,16 +161,21 @@ public:
     /// @brief Set the path where the bootloader will be installed
     void setBootLoaderInstallPath( const QString& path );
 
-    /** @brief Initialize the default layout that will be applied
+    /** @brief Get the partition layout that will be applied.
      *
-     * See PartitionLayout::init()
+     * Layouts are applied only for erase and replace operations.
      */
-    void initLayout( FileSystem::Type defaultFsType, const QVariantList& config = QVariantList() );
+    PartitionLayout& partitionLayout() { return m_partLayout; }
 
-    void layoutApply( Device* dev, qint64 firstSector, qint64 lastSector, QString luksPassphrase );
     void layoutApply( Device* dev,
                       qint64 firstSector,
                       qint64 lastSector,
+                      Config::LuksGeneration luksFsType,
+                      QString luksPassphrase );
+    void layoutApply( Device* dev,
+                      qint64 firstSector,
+                      qint64 lastSector,
+                      Config::LuksGeneration luksFsType,
                       QString luksPassphrase,
                       PartitionNode* parent,
                       const PartitionRole& role );
@@ -239,7 +247,6 @@ Q_SIGNALS:
     void deviceReverted( Device* device );
 
 private:
-    struct DeviceInfo;
     void refreshAfterModelChange();
 
     void doInit();
@@ -250,7 +257,7 @@ private:
 
     DeviceInfo* infoForDevice( const Device* ) const;
 
-    CalamaresUtils::Partition::KPMManager m_kpmcore;
+    Calamares::Partition::KPMManager m_kpmcore;
 
     QList< DeviceInfo* > m_deviceInfos;
     QList< Partition* > m_efiSystemPartitions;
