@@ -31,20 +31,18 @@
 #include "ui_CreatePartitionTableDialog.h"
 #include "ui_PartitionPage.h"
 
+#include "Branding.h"
 #include "GlobalStorage.h"
 #include "JobQueue.h"
 #include "partition/PartitionQuery.h"
 #include "utils/Logger.h"
 #include "utils/Retranslator.h"
-
-#include "Branding.h"
+#include "widgets/TranslationFix.h"
 
 // KPMcore
 #include <kpmcore/core/device.h>
 #include <kpmcore/core/partition.h>
-#ifdef WITH_KPMCORE4API
 #include <kpmcore/core/softwareraid.h>
-#endif
 #include <kpmcore/ops/deactivatevolumegroupoperation.h>
 #include <kpmcore/ops/removevolumegroupoperation.h>
 
@@ -125,8 +123,8 @@ PartitionPage::~PartitionPage() {}
 void
 PartitionPage::updateButtons()
 {
-    bool create = false, createTable = false, edit = false, del = false, currentDeviceIsVG = false,
-         isDeactivable = false;
+    bool allow_create = false, allow_create_table = false, allow_edit = false, allow_delete = false;
+    bool currentDeviceIsVG = false, isDeactivable = false;
     bool isRemovable = false, isVGdeactivated = false;
 
     QModelIndex index = m_ui->partitionTreeView->currentIndex();
@@ -136,12 +134,21 @@ PartitionPage::updateButtons()
         Q_ASSERT( model );
         Partition* partition = model->partitionForIndex( index );
         Q_ASSERT( partition );
-        bool isFree = CalamaresUtils::Partition::isPartitionFreeSpace( partition );
-        bool isExtended = partition->roles().has( PartitionRole::Extended );
+        const bool isFree = Calamares::Partition::isPartitionFreeSpace( partition );
+        const bool isExtended = partition->roles().has( PartitionRole::Extended );
 
-        bool isInVG = m_core->isInVG( partition );
+        // An extended partition can have a "free space" child; that one does
+        // not count as a real child. If there are more children, at least one
+        // is a real one and we should not allow the extended partition to be
+        // deleted.
+        const bool hasChildren = isExtended
+            && ( partition->children().length() > 1
+                 || ( partition->children().length() == 1
+                      && !Calamares::Partition::isPartitionFreeSpace( partition->children().at( 0 ) ) ) );
 
-        create = isFree;
+        const bool isInVG = m_core->isInVG( partition );
+
+        allow_create = isFree;
 
         // Keep it simple for now: do not support editing extended partitions as
         // it does not work with our current edit implementation which is
@@ -150,8 +157,8 @@ PartitionPage::updateButtons()
         // inside them, so an edit must be applied without altering the job
         // order.
         // TODO: See if LVM PVs can be edited in Calamares
-        edit = !isFree && !isExtended;
-        del = !isFree && !isInVG;
+        allow_edit = !isFree && !isExtended;
+        allow_delete = !isFree && !isInVG && !hasChildren;
     }
 
     if ( m_ui->deviceComboBox->currentIndex() >= 0 )
@@ -168,16 +175,14 @@ PartitionPage::updateButtons()
         }
         else if ( device->type() != Device::Type::LVM_Device )
         {
-            createTable = true;
+            allow_create_table = true;
 
-#ifdef WITH_KPMCORE4API
             if ( device->type() == Device::Type::SoftwareRAID_Device
                  && static_cast< SoftwareRAID* >( device )->status() == SoftwareRAID::Status::Inactive )
             {
-                createTable = false;
-                create = false;
+                allow_create_table = false;
+                allow_create = false;
             }
-#endif
         }
         else
         {
@@ -197,10 +202,10 @@ PartitionPage::updateButtons()
         }
     }
 
-    m_ui->createButton->setEnabled( create );
-    m_ui->editButton->setEnabled( edit );
-    m_ui->deleteButton->setEnabled( del );
-    m_ui->newPartitionTableButton->setEnabled( createTable );
+    m_ui->createButton->setEnabled( allow_create );
+    m_ui->editButton->setEnabled( allow_edit );
+    m_ui->deleteButton->setEnabled( allow_delete );
+    m_ui->newPartitionTableButton->setEnabled( allow_create_table );
     m_ui->resizeVolumeGroupButton->setEnabled( currentDeviceIsVG && !isVGdeactivated );
     m_ui->deactivateVolumeGroupButton->setEnabled( currentDeviceIsVG && isDeactivable && !isVGdeactivated );
     m_ui->removeVolumeGroupButton->setEnabled( currentDeviceIsVG && isRemovable );
@@ -249,13 +254,16 @@ PartitionPage::checkCanCreate( Device* device )
 
         if ( ( table->numPrimaries() >= table->maxPrimaries() ) && !table->hasExtended() )
         {
-            QMessageBox::warning(
-                this,
+            QMessageBox mb(
+                QMessageBox::Warning,
                 tr( "Can not create new partition" ),
                 tr( "The partition table on %1 already has %2 primary partitions, and no more can be added. "
                     "Please remove one primary partition and add an extended partition, instead." )
                     .arg( device->name() )
-                    .arg( table->numPrimaries() ) );
+                    .arg( table->numPrimaries() ),
+                QMessageBox::Ok );
+            Calamares::fixButtonLabels( &mb );
+            mb.exec();
             return false;
         }
         return true;
@@ -276,10 +284,12 @@ PartitionPage::onNewVolumeGroupClicked()
     QVector< const Partition* > availablePVs;
 
     for ( const Partition* p : m_core->lvmPVs() )
+    {
         if ( !m_core->isInVG( p ) )
         {
             availablePVs << p;
         }
+    }
 
     QPointer< CreateVolumeGroupDialog > dlg
         = new CreateVolumeGroupDialog( vgName, selectedPVs, availablePVs, peSize, this );
@@ -334,10 +344,12 @@ PartitionPage::onResizeVolumeGroupClicked()
     QVector< const Partition* > selectedPVs;
 
     for ( const Partition* p : m_core->lvmPVs() )
+    {
         if ( !m_core->isInVG( p ) )
         {
             availablePVs << p;
         }
+    }
 
     QPointer< ResizeVolumeGroupDialog > dlg = new ResizeVolumeGroupDialog( device, availablePVs, selectedPVs, this );
 
@@ -411,7 +423,7 @@ PartitionPage::onEditClicked()
     Partition* partition = model->partitionForIndex( index );
     Q_ASSERT( partition );
 
-    if ( CalamaresUtils::Partition::isPartitionNew( partition ) )
+    if ( Calamares::Partition::isPartitionNew( partition ) )
     {
         updatePartitionToCreate( model->device(), partition );
     }
@@ -439,15 +451,18 @@ void
 PartitionPage::onRevertClicked()
 {
     ScanningDialog::run(
-        QtConcurrent::run( [this] {
-            QMutexLocker locker( &m_revertMutex );
+        QtConcurrent::run(
+            [ this ]
+            {
+                QMutexLocker locker( &m_revertMutex );
 
-            int oldIndex = m_ui->deviceComboBox->currentIndex();
-            m_core->revertAllDevices();
-            m_ui->deviceComboBox->setCurrentIndex( ( oldIndex < 0 ) ? 0 : oldIndex );
-            updateFromCurrentDevice();
-        } ),
-        [this] {
+                int oldIndex = m_ui->deviceComboBox->currentIndex();
+                m_core->revertAllDevices();
+                m_ui->deviceComboBox->setCurrentIndex( ( oldIndex < 0 ) ? 0 : oldIndex );
+                updateFromCurrentDevice();
+            } ),
+        [ this ]
+        {
             m_lastSelectedBootLoaderIndex = -1;
             if ( m_ui->bootLoaderComboBox->currentIndex() < 0 )
             {
@@ -476,7 +491,7 @@ PartitionPage::onPartitionViewActivated()
     // but I don't expect there will be other occurences of triggering the same
     // action from multiple UI elements in this page, so it does not feel worth
     // the price.
-    if ( CalamaresUtils::Partition::isPartitionFreeSpace( partition ) )
+    if ( Calamares::Partition::isPartitionFreeSpace( partition ) )
     {
         m_ui->createButton->click();
     }
@@ -594,7 +609,8 @@ PartitionPage::updateFromCurrentDevice()
         m_ui->partitionBarsView->selectionModel(),
         &QItemSelectionModel::currentChanged,
         this,
-        [=] {
+        [ = ]
+        {
             QModelIndex selectedIndex = m_ui->partitionBarsView->selectionModel()->currentIndex();
             selectedIndex = selectedIndex.sibling( selectedIndex.row(), 0 );
             m_ui->partitionBarsView->setCurrentIndex( selectedIndex );
@@ -613,7 +629,7 @@ PartitionPage::updateFromCurrentDevice()
     // model changes
     connect( m_ui->partitionTreeView->selectionModel(),
              &QItemSelectionModel::currentChanged,
-             [this]( const QModelIndex&, const QModelIndex& ) { updateButtons(); } );
+             [ this ]( const QModelIndex&, const QModelIndex& ) { updateButtons(); } );
     connect( model, &QAbstractItemModel::modelReset, this, &PartitionPage::onPartitionModelReset );
 }
 
