@@ -11,6 +11,7 @@
 
 #include "FillGlobalStorageJob.h"
 
+#include "compat/Variant.h"
 #include "core/KPMHelpers.h"
 #include "core/PartitionInfo.h"
 
@@ -26,15 +27,16 @@
 #include <kpmcore/core/partition.h>
 #include <kpmcore/fs/filesystem.h>
 #include <kpmcore/fs/luks.h>
+#include <kpmcore/fs/luks2.h>
 
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
 #include <QProcess>
 
-using CalamaresUtils::Partition::PartitionIterator;
-using CalamaresUtils::Partition::untranslatedFS;
-using CalamaresUtils::Partition::userVisibleFS;
+using Calamares::Partition::PartitionIterator;
+using Calamares::Partition::untranslatedFS;
+using Calamares::Partition::userVisibleFS;
 
 typedef QHash< QString, QString > UuidForPartitionHash;
 
@@ -88,30 +90,40 @@ mapForPartition( Partition* partition, const QString& uuid )
     map[ "mountPoint" ] = PartitionInfo::mountPoint( partition );
     map[ "fsName" ] = userVisibleFS( partition->fileSystem() );
     map[ "fs" ] = untranslatedFS( partition->fileSystem() );
-#ifdef WITH_KPMCORE42API
     map[ "parttype" ] = partition->type();
     map[ "partattrs" ] = partition->attributes();
     map[ "features" ] = partition->fileSystem().features();
-#endif
+
     if ( partition->fileSystem().type() == FileSystem::Luks
          && dynamic_cast< FS::luks& >( partition->fileSystem() ).innerFS() )
     {
         map[ "fs" ] = untranslatedFS( dynamic_cast< FS::luks& >( partition->fileSystem() ).innerFS() );
     }
+    if ( partition->fileSystem().type() == FileSystem::Luks2
+         && dynamic_cast< FS::luks2& >( partition->fileSystem() ).innerFS() )
+    {
+        map[ "fs" ] = untranslatedFS( dynamic_cast< FS::luks2& >( partition->fileSystem() ).innerFS() );
+    }
+
     map[ "uuid" ] = uuid;
     map[ "claimed" ] = PartitionInfo::format( partition );  // If we formatted it, it's ours
 
     // Debugging for inside the loop in createPartitionList(),
     // so indent a bit
     Logger::CDebug deb;
-    using TR = Logger::DebugRow< const char* const, const QString& >;
+    using TR = Logger::DebugRow< const char* const, const QString >;
+    // clang-format off
     deb << Logger::SubEntry << "mapping for" << partition->partitionPath() << partition->deviceNode()
-        << TR( "partlabel", map[ "partlabel" ].toString() ) << TR( "partuuid", map[ "partuuid" ].toString() )
-        << TR( "parttype", map[ "parttype" ].toString() ) << TR( "partattrs", map[ "partattrs" ].toString() )
-        << TR( "mountPoint:", PartitionInfo::mountPoint( partition ) ) << TR( "fs:", map[ "fs" ].toString() )
-        << TR( "fsName", map[ "fsName" ].toString() ) << TR( "uuid", uuid )
+        << TR( "partlabel", map[ "partlabel" ].toString() )
+        << TR( "partition-uuid (partuuid)", Logger::RedactedName( "PartUUID", map[ "partuuid" ].toString() ) )
+        << TR( "parttype", map[ "parttype" ].toString() )
+        << TR( "partattrs", map[ "partattrs" ].toString() )
+        << TR( "mountPoint:", PartitionInfo::mountPoint( partition ) )
+        << TR( "fs:", map[ "fs" ].toString() )
+        << TR( "fsName", map[ "fsName" ].toString() )
+        << TR( "filesystem-uuid (uuid)", Logger::RedactedName( "FSUUID", uuid ) )
         << TR( "claimed", map[ "claimed" ].toString() );
-
+    // clang-format on
     if ( partition->roles().has( PartitionRole::Luks ) )
     {
         const FileSystem& fsRef = partition->fileSystem();
@@ -135,7 +147,7 @@ prettyFileSystemFeatures( const QVariantMap& features )
     for ( const auto& key : features.keys() )
     {
         const auto& value = features.value( key );
-        if ( value.type() == QVariant::Bool )
+        if ( Calamares::typeOf( value ) == Calamares::BoolVariantType )
         {
             if ( value.toBool() )
             {
@@ -176,7 +188,7 @@ FillGlobalStorageJob::prettyDescription() const
     const auto partitionList = createPartitionList();
     for ( const QVariant& partitionItem : partitionList )
     {
-        if ( partitionItem.type() == QVariant::Map )
+        if ( Calamares::typeOf( partitionItem ) == Calamares::MapVariantType )
         {
             QVariantMap partitionMap = partitionItem.toMap();
             QString path = partitionMap.value( "device" ).toString();
@@ -294,14 +306,14 @@ FillGlobalStorageJob::prettyStatusMessage() const
  * .. mark as "2" if it's one of the claimed / in-use FSses
  *
  * Stores a GS key called "filesystem_use" with this mapping.
- * @see CalamaresUtils::Partition::useFilesystemGS()
+ * @see Calamares::Partition::useFilesystemGS()
  */
 static void
 storeFSUse( Calamares::GlobalStorage* storage, const QVariantList& partitions )
 {
     if ( storage )
     {
-        CalamaresUtils::Partition::clearFilesystemGS( storage );
+        Calamares::Partition::clearFilesystemGS( storage );
         for ( const auto& p : partitions )
         {
             const auto pmap = p.toMap();
@@ -313,7 +325,7 @@ storeFSUse( Calamares::GlobalStorage* storage, const QVariantList& partitions )
                 continue;
             }
 
-            CalamaresUtils::Partition::useFilesystemGS( storage, fs, true );
+            Calamares::Partition::useFilesystemGS( storage, fs, true );
         }
     }
 }
