@@ -14,8 +14,8 @@
 #include "core/KPMHelpers.h"
 
 #include "partition/FileSystem.h"
-#include "utils/CalamaresUtilsSystem.h"
 #include "utils/Logger.h"
+#include "utils/System.h"
 
 #include <kpmcore/core/device.h>
 #include <kpmcore/core/partition.h>
@@ -24,8 +24,8 @@
 #include <kpmcore/ops/createfilesystemoperation.h>
 #include <kpmcore/util/report.h>
 
-using CalamaresUtils::Partition::untranslatedFS;
-using CalamaresUtils::Partition::userVisibleFS;
+using Calamares::Partition::untranslatedFS;
+using Calamares::Partition::userVisibleFS;
 
 FormatPartitionJob::FormatPartitionJob( Device* device, Partition* partition )
     : PartitionJob( partition )
@@ -43,7 +43,6 @@ FormatPartitionJob::prettyName() const
         .arg( m_device->name() );
 }
 
-
 QString
 FormatPartitionJob::prettyDescription() const
 {
@@ -54,7 +53,6 @@ FormatPartitionJob::prettyDescription() const
         .arg( m_partition->capacity() / 1024 / 1024 );
 }
 
-
 QString
 FormatPartitionJob::prettyStatusMessage() const
 {
@@ -67,7 +65,6 @@ FormatPartitionJob::prettyStatusMessage() const
         .arg( partitionLabel, userVisibleFS( m_partition->fileSystem() ) );
 }
 
-
 Calamares::JobResult
 FormatPartitionJob::exec()
 {
@@ -81,8 +78,8 @@ FormatPartitionJob::exec()
         // (ignoring whether this succeeds). Requires a sufficiently-new
         // xfs_admin and xfs_repair and might be made obsolete by newer
         // kpmcore releases.
-        CalamaresUtils::System::runCommand( { "xfs_admin", "-O", "bigtime=1", m_partition->partitionPath() },
-                                            std::chrono::seconds( 60 ) );
+        Calamares::System::runCommand( { "xfs_admin", "-O", "bigtime=1", m_partition->partitionPath() },
+                                       std::chrono::seconds( 60 ) );
     }
     return r;
 }
